@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2013 Aurimas Cernius
+ * Copyright (C) 2013,2015 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,12 +18,17 @@
  */
 
 
+#include <cstring>
+
 #include "ignote.hpp"
 #include "mainwindow.hpp"
 #include "notewindow.hpp"
 
 namespace gnote {
 
+int MainWindow::s_use_client_side_decorations = -1;
+
+
 MainWindow *MainWindow::get_owning(Gtk::Widget & widget)
 {
   Gtk::Container *container = widget.get_parent();
@@ -96,6 +101,20 @@ MainWindow *MainWindow::present_default(const Note::Ptr & note)
   return win;
 }
 
+bool MainWindow::use_client_side_decorations()
+{
+  if (s_use_client_side_decorations < 0) {
+    if(std::strcmp(std::getenv("DESKTOP_SESSION"), "gnome") == 0) {
+      s_use_client_side_decorations = 1;
+    }
+    else {
+      s_use_client_side_decorations = 0;
+    }
+  }
+
+  return s_use_client_side_decorations;
+}
+
 
 MainWindow::MainWindow(const std::string & title)
   : utils::ForcedPresentWindow(title)
