@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2014 Aurimas Cernius
+ * Copyright (C) 2011-2015 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -617,7 +617,8 @@ namespace gnote {
     if(m_global_keys)
       m_global_keys->enabled(m_enabled);
     FOREACH(const Glib::RefPtr<Gtk::Action> & action, get_widget_actions()) {
-      if(Glib::RefPtr<NonModifyingNoteAction>::cast_dynamic(action) == 0) {
+      // A list includes empty actions to mark separators, non-modifying actions are always enabled
+      if(action != 0 && Glib::RefPtr<NonModifyingNoteAction>::cast_dynamic(action) == 0) {
         action->set_sensitive(enable);
       }
     }
